/*
 * JavaScript for Cambridge English-Chinese (Simplified) Dictionary
 * 
 * Based on jQuery v3.2.1
 * Updated on: March 18, 2018
 * 
 * Copyright © 2016-2018 Frank
 * Licensed under GNU GPLv3
 * 
 */

$(document).ready(function() {
  var langZhCn = $('.english-chinese');

  var entriesZhCn = langZhCn.find('.entry-body__el');
  
  var sensesZhCn = langZhCn.find('.pos-body .sense-block,.pv-body .sense-block, .idiom-block .def-block');
  
  var senseHeadingsZhCn = langZhCn.find('.txt-block');
  
  var guidewords = $('.guideword, .gw');

  var slidingItems = $('.extraexamps, .smartt, .usagenote');
  
  // Detect BlueDict
  try{ 
    var blueDict = isBlueDict();
  } catch (e) {
    var blueDict = false;
  }

  // Hide "Contents"
  $('.unstyled-nest .section ul').hide();
  // Hide "More examples", "Notes:", "Thesaurus: synonyms and related words"
  slidingItems.find('.pad-indent, >div').hide();

  var btn = $("<input type='button' id='toggle-ch' value='HIDE'>");
  
  $(".trans").show();
  if ($("#toggle-ch").length <= 0) {
    $(".entry").prepend(btn);

    btn.click(function(){
      if ( $(this).val() == "SHOW" ) {
        $(".trans").show();
        $(this).val("HIDE");
      } 
      else { 
        $(".trans").hide();
        $(this).val("SHOW");
      }
    });

    $(".def").click(function(){
       var samp = $(this).next().next();
       if (samp.is(':visible')) {
         samp.hide();
       } else { 
         samp.show();
       }
    });
  }

  // Add sense index (English–Chinese(Simplified))
  if (sensesZhCn.length > 1 && $('.sense_index_zhcn').length === 0) {
    langZhCn.first().before('<a name="sense_index_zhcn"></a><div class="sense_index_zhcn"><div class="contents_zhcn">Contents</div><div class="sense_list_zhcn"></div></div>');
    
    var senseIndexZhCn = $('.sense_index_zhcn');
    var contentsZhCn = $('.contents_zhcn');
    var senseListZhCn = $('.sense_list_zhcn');
    
    // Add animation to "Contents"
    contentsZhCn.click(function() {
      contentsZhCn.toggleClass('in');
      contentsZhCn.next().slideToggle();
    });
    
    sensesZhCn.each(function(i) {
      // Add senses
      if (blueDict) {
        var backToIndex = $('<a href="entry://#sense_index_zhcn"></a>');
      } else {
        var backToIndex = $('<a href="#sense_index_zhcn"></a>');
      }
      
      var senseHeading = $(this).find('.txt-block');
      var hw = $(this).closest('.entry-body__el').find('.hw').text();
      var partOfSpeech = $(this).closest('.entry-body__el').find('.pos-header .posgram').text();
      
      var pvBlock = $(this).closest('.pv-block');
      var idiomBlock = $(this).closest('.idiom-block');
      
      // Phrasal verbs
      if (pvBlock.length) {
        if (senseHeading.length) {
          if (blueDict) {
            senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · phrasal verb ' + senseHeading.text() + '</a>');
          } else {
            senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · phrasal verb ' + senseHeading.text() + '</a>');
          }
          
          $(this).before('<a name="sense_zhcn_' + i + '"></a>');
          senseHeading.wrap(backToIndex);
        } else {
          if (blueDict) {
            senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' </a>');
          } else {
            senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' </a>');
          }
          
          $(this).before('<a name="sense_zhcn_' + i + '"></a>');
        }
      // Idioms
      } else if (idiomBlock.length) {
        if (blueDict) {
          senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · idiom</a>');
        } else {
          senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · idiom</a>');
        }

        $(this).before('<a name="sense_zhcn_' + i + '"></a>');
      // Normal entries
      } else {
        if (senseHeading.length) {
          if (blueDict) {
            senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + senseHeading.children('.hw').text() + ' · ' + partOfSpeech + ' ' + senseHeading.children('.guideword').text() + '</a>');
          } else {
            senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + senseHeading.children('.hw').text() + ' · ' + partOfSpeech + ' ' + senseHeading.children('.guideword').text() + '</a>');
          }
          
          $(this).before('<a name="sense_zhcn_' + i + '"></a>');
          senseHeading.wrap(backToIndex);
        } else {
          if (partOfSpeech.length === 0) {
              if (blueDict) {
                  senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + '</a>');
              } else {
                  senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + '</a>');
              }
          } else {
              if (blueDict) {
                  senseListZhCn.append('<a href="entry://#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · ' + partOfSpeech + '</a>');
              } else {
                  senseListZhCn.append('<a href="#sense_zhcn_' + i + '" class="sense">' + (i + 1) + '. ' + hw + ' · ' + partOfSpeech + '</a>');
              }
          }
          
          $(this).before('<a name="sense_zhcn_' + i + '"></a>');
        }
      }
    });
    senseIndexZhCn.hide();
    senseListZhCn.hide();
    if (langZhCn.is(':visible')) {
      senseIndexZhCn.fadeIn();
    }
  }
  
  //  Remove the mouse over effect there's only one sense within the entry
  if (sensesZhCn.length === 1) {
    senseHeadingsZhCn.addClass('only');
  }
  
  // Sliding items
  slidingItems.each(function() {
    // Initialization
    if ($(this).attr('class') === 'smartt') {
      if ($(this).find('> div').is(':visible')) {
        $(this).find('.accord-basic').addClass('in');
      }
    } else {
      if ($(this).find('.pad-indent').is(':visible')) {
        $(this).find('.accord-basic').addClass('in');
      }
    }
    // Add animation
    $(this).find('.accord-basic').off().click(function() {
      $(this).toggleClass('in');
      $(this).next().slideToggle();
    });
  });

  // Prettify borders
  if (senseIndexZhCn) {
    entriesZhCn.first().css('border-top-right-radius', '0px');
  }
});

  // Illustrations
function HongYang_toggleImg(ele) {
    if (ele.style.maxHeight == 'none') {
        ele.style.maxHeight = '3.12em';
        ele.style.maxWidth = 'none';
    } else {
        ele.style.maxHeight = 'none';
        ele.style.maxWidth = '540px';
    }
}

function HY_toggleImg(ele) {
    if (ele.style.maxHeight == 'none') {
        ele.style.maxHeight = '3.12em';
        ele.style.maxWidth = 'none';
    } else {
        ele.style.maxHeight = 'none';
        ele.style.maxWidth = '1080px';
    }
}

function HongYangJie_toggleImg(ele) {
    if (ele.style.maxHeight == 'none') {
        ele.style.maxHeight = '3.12em';
        ele.style.maxWidth = 'none';
    } else {
        ele.style.maxHeight = 'none';
        ele.style.maxWidth = '1440px';
    }
}